intelmq.bots.experts.trusted_introducer_lookup package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.experts.trusted_introducer_lookup package

## Submodules

## intelmq.bots.experts.trusted_introducer_lookup.expert module

Trusted Introducer Expert

SPDX-FileCopyrightText: 2021 Intelmq Team <intelmq-team@cert.at> SPDX-License-Identifier: AGPL-3.0-or-later

intelmq.bots.experts.trusted_introducer_lookup.expert.BOT

  alias of `intelmq.bots.experts.trusted_introducer_lookup.expert.TrustedIntroducerLookupExpertBot`

class intelmq.bots.experts.trusted_introducer_lookup.expert.TrustedIntroducerLookupExpertBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.ExpertBot`, `intelmq.lib.mixins.http.HttpMixin`

  Get trusted introducer lookup data

  init()
  order: str = 'domain, asn'
  overwrite: bool = True
  process()

## Module contents